Welcome to Slicer Package Manager’s documentation! — Slicer Package Manager 0.1.0 documentation

# Welcome to Slicer Package Manager’s documentation!

The Slicer Package Manager includes a REST API service and CLI built on Girder for downloading, uploading and organizing application and extension packages for both 3D Slicer and 3D Slicer-based applications.

- Overview
- Concepts
- Commands shell (CLI)
- FAQ
- Server Installation
- Developer Guide
- Credits
- Making a release
- Release Notes

# Indices and tables

- Index

- Module Index

- Search Page